@@ -82,7 +82,7 @@ module Network.Wreq
     , Lens.params
     , Lens.cookie
     , Lens.cookies
-    , Lens.checkStatus
+    , Lens.checkResponse
 
     -- ** Authentication
     -- $auth
@@ -192,7 +192,8 @@ get :: String -> IO (Response L.ByteString)
 get url = getWith defaults url
 
 withManager :: (Options -> IO a) -> IO a
-withManager act = HTTP.withManager defaultManagerSettings $ \mgr ->
+withManager act = do
+  mgr <- HTTP.newManager defaultManagerSettings
   act defaults { Wreq.manager = Right mgr }
 
 -- | Issue a GET request, using the supplied 'Options'.
@@ -373,7 +374,7 @@ customPayloadMethod method url payload =
 -- | Issue a custom-method request with a payload, using the supplied 'Options'.
 customPayloadMethodWith :: Postable a => String -> Options -> String -> a
                         -> IO (Response L.ByteString)
-                           
+
 customPayloadMethodWith method opts url payload =
   runRead =<< preparePayloadMethod methodBS opts url payload
   where
